# Changelog

## 0.1.1 (2026-03-17)

Full Changelog: [v0.1.0...v0.1.1](https://github.com/abundai-org/abundai-python/compare/v0.1.0...v0.1.1)

### Bug Fixes

* **pydantic:** do not pass `by_alias` unless set ([1280176](https://github.com/abundai-org/abundai-python/commit/12801761c4ca5aa621bc96997e4df4dcdecbd50a))


### Chores

* **ci:** bump uv version ([194267e](https://github.com/abundai-org/abundai-python/commit/194267e0afb53f8b4f39711b93c7ee030ccf9952))
* **ci:** skip uploading artifacts on stainless-internal branches ([448ed63](https://github.com/abundai-org/abundai-python/commit/448ed63b034864981878fc0b2a10d616d3edd806))
* format all `api.md` files ([70e039b](https://github.com/abundai-org/abundai-python/commit/70e039b4845912fa4cc2d2fbb99cd9fe1aa1b6a1))
* **internal:** add request options to SSE classes ([a1a2cd2](https://github.com/abundai-org/abundai-python/commit/a1a2cd25b1242b9019be3aa9d379bdbdf6604183))
* **internal:** bump dependencies ([52cce45](https://github.com/abundai-org/abundai-python/commit/52cce45364eef6225a604941247b15b82e2eb57b))
* **internal:** codegen related update ([2878b41](https://github.com/abundai-org/abundai-python/commit/2878b41676031c6f196599ce1e7efe0df228a4fd))
* **internal:** fix lint error on Python 3.14 ([0adeba0](https://github.com/abundai-org/abundai-python/commit/0adeba095e5f186ca42a240c559e16c16159ad4a))
* **internal:** make `test_proxy_environment_variables` more resilient ([4e79b36](https://github.com/abundai-org/abundai-python/commit/4e79b3654f9f89dfa4106a5ebda7cc1fc688b315))
* **internal:** make `test_proxy_environment_variables` more resilient to env ([406eb67](https://github.com/abundai-org/abundai-python/commit/406eb679a00502cdef3d94f4b0b04105c19d46d1))
* **internal:** refactor authentication internals ([c903396](https://github.com/abundai-org/abundai-python/commit/c9033966c058068e51855753dfe18d634cd58df9))
* **internal:** remove mock server code ([8b46aed](https://github.com/abundai-org/abundai-python/commit/8b46aedfd1eb0e216992b99d954221b17cbf95df))
* update mock server docs ([400e4c1](https://github.com/abundai-org/abundai-python/commit/400e4c19244d432223df76d51404929d7bf0fe5a))
* update placeholder string ([e1ecf60](https://github.com/abundai-org/abundai-python/commit/e1ecf60df3a2bdab4ea781c4d04f525dc85f533c))

## 0.1.0 (2026-02-06)

Full Changelog: [v0.0.3...v0.1.0](https://github.com/abundai-org/abundai-python/compare/v0.0.3...v0.1.0)

### Features

* **api:** api update ([e0e196e](https://github.com/abundai-org/abundai-python/commit/e0e196ec34fca8bfe61889dfe24a9d997aa160bb))


### Chores

* update SDK settings ([9936e95](https://github.com/abundai-org/abundai-python/commit/9936e957706803a58d78836f0f057d58c3da4159))
* update SDK settings ([2db5f31](https://github.com/abundai-org/abundai-python/commit/2db5f317e2809d93875ae06312d4d43c9cead572))

## 0.0.3 (2026-02-05)

Full Changelog: [v0.0.2...v0.0.3](https://github.com/abundai-org/abundai-python/compare/v0.0.2...v0.0.3)

### Chores

* update SDK settings ([bb2ed60](https://github.com/abundai-org/abundai-python/commit/bb2ed60995a2b239e417f4eb4a8eb883ded0392e))

## 0.0.2 (2026-02-05)

Full Changelog: [v0.0.1...v0.0.2](https://github.com/abundai-org/abundai-python/compare/v0.0.1...v0.0.2)

### Chores

* configure new SDK language ([52868d3](https://github.com/abundai-org/abundai-python/commit/52868d3d2442826665c9f595282f3992dcd8dcd1))
* update SDK settings ([2a52533](https://github.com/abundai-org/abundai-python/commit/2a52533bc77df47f957bbe8126ef546b1efb82bf))
* update SDK settings ([ad76b9c](https://github.com/abundai-org/abundai-python/commit/ad76b9ca10854d12ba2a2bb35b26c3ba8190646f))
